@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: lens
 version: 4.13.2.1
-id: lens-4.13.2.1-7da1232efa9fbb46f4651315f7427146
-key: lens_2cH2us51VaEJEqkl1SW1lG
+id: lens-4.13.2.1-3b086cb541bae44e8089b135a290af93
+key: lens_CQGTvKhRr3o7ECIQ5skDMY
 license: BSD3
 copyright: Copyright (C) 2012-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -122,37 +122,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/lens-4.13.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/lens-4.13.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/lens-4.13.2.1
-hs-libraries: HSlens-4.13.2.1-2cH2us51VaEJEqkl1SW1lG
+hs-libraries: HSlens-4.13.2.1-CQGTvKhRr3o7ECIQ5skDMY
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
-    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
+    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    comonad-5-a91321d086a2de4a04a44d60c347669e
+    comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
+    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
     distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
+    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    kan-extensions-5.0.1-64eb21bb3d73057703a5a6cf47edf0b3
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    kan-extensions-5.0.1-9d0c832e36b69937523b7bdb128f89cd
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     parallel-3.2.1.0-29613111a366ee1bb108c8999c15ba21
-    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
+    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
     reflection-2.1.2-9b9b2f9fb5d90bced15b1aba04e6558f
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
+    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
 haddock-interfaces: /usr/share/doc/haskell-lens/html/lens.haddock
 haddock-html: /usr/share/doc/haskell-lens/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
